using Microsoft.AspNetCore.Mvc;
using DndBattlefield.Data;
using DndBattlefield.Models;
using DndBattlefield.DTO;

namespace DndBattlefield.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class TerrainController : ControllerBase
    {
        private readonly AppDbContext _db;

        public TerrainController(AppDbContext db)
        {
            _db = db;
        }

        // POST: /api/terrain
        [HttpPost]
        public async Task<ActionResult<TerrainDto>> CreateTerrain([FromBody] Terrain terrain)
        {
            _db.Terrains.Add(terrain);
            await _db.SaveChangesAsync();

            var dto = new TerrainDto
            {
                ID =  terrain.ID,
                Name = terrain.Name,
                Type = terrain.Type,
                Image = terrain.Image,
                X = terrain.X, 
                Y = terrain.Y, 
                BlocksMovement = terrain.BlocksMovement, 
                MovementCost = terrain.MovementCost, 
                SpillepladeID = terrain.SpillepladeID
            };

            return Ok(dto);
        }

        // PUT: /api/terrain/{id}
        [HttpPut("{id}")]
        public async Task<IActionResult> UpdatePosition(int id, [FromBody] TerrainDto dto)
        {
            var terrain = await _db.Terrains.FindAsync(id);
            if (terrain == null) return NotFound();

            terrain.X = dto.X;
            terrain.Y = dto.Y;

            await _db.SaveChangesAsync();
            return NoContent();
        }

        //Delete: /api/terrain/{id}
        [HttpDelete("{id}")]
        public async Task<IActionResult> DeleteTerrain(int id)
        {
            var terrain = await _db.Terrains.FindAsync(id);
            if (terrain == null) return NotFound();

            _db.Terrains.Remove(terrain);
            await _db.SaveChangesAsync();

            return NoContent();
        }
        
    }
}
